/*
 *  dJEP - DESCRIPTION OF PACKAGE
 *  Copyright (C) 2004 Ross M. Lodge
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  The author of this program grants you the ability to use this code
 *  in conjunction with code that is covered under the Open Gaming License
 *
 *  Floor.java
 *
 *  Created on Jan 31, 2004, 11:11:46 AM
 */
package com.electronicmuse.djep.function;

import java.util.Stack;

import com.electronicmuse.djep.ParseException;

/**
 * <p>
 * Passes the single argument on to Math.floor, which "Returns the largest
 * (closest to positive infinity) double value that is not greater than the
 * argument and is equal to a mathematical integer."
 * </p>
 * 
 * @author Ross M. Lodge
 *  
 */
public class Floor extends PostfixMathCommand
{

	/**
	 * <p>
	 * Sets the number of parameters = 1
	 * </p>
	 * 
	 */
	public Floor()
	{
		super();
		numberOfParameters = 1;
	}

	/**
	 * <p>The run command for the JEP framework.  This receives the arguments
	 * to the operator as a stack, pops off the one it needs, does type checking,
	 * passes the parameter to Math.floor, and then returns the result.</p>
	 * 
	 * @see org.nfunk.jep.function.PostfixMathCommandI#run(java.util.Stack)
	 */
	public void run(Stack inStack) throws ParseException
	{
		// check the stack
		checkStack(inStack);

		// get the parameter from the stack
		Object param = inStack.pop();

		// check whether the argument is of the right type
		if (param instanceof Number)
		{
			double result = ((Number)param).doubleValue();
			result = Math.floor(result);
			inStack.push(new Double(result));
		}
		else
		{
			throw new ParseException("Invalid parameter type");
		}
	}
}
