/*
 *  dJEP - DESCRIPTION OF PACKAGE
 *  Copyright (C) 2004 Ross M. Lodge
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  The author of this program grants you the ability to use this code
 *  in conjunction with code that is covered under the Open Gaming License
 *
 *  If.java
 *
 *  Created on Jul 3, 2004, 1:14:30 PM
 */
package com.electronicmuse.djep.function;

import java.util.Stack;

import com.electronicmuse.djep.ParseException;

/**
 * <p>
 * If class; extends PostfixMathCommand.
 * This class accepts three agruments.  The first is a number interpreted as a boolean.
 * The other two may be any supported classes.  If the first argument is > 0, the second
 * argument is returned.  Otherwise, the third argument is returned.
 * </p>
 * <p>
 * So, given if(x,y,z), y is returned if x is > 0, and z is returned otherise.
 * </p>
 * @author Ross M. Lodge
 *
 */
public class If extends PostfixMathCommand {
	/**
	 * <p>
	 * Initializes the number of parameters to = 3, indicating three
	 * number of parameters.
	 * </p>
	 *  
	 */
	public If() {
		super();
		numberOfParameters = 3;
	}

	/**
	 * <p>
	 * Evaluates the three parameters.  The first may be a subclass of Number,
	 * or a Boolean.  The second and third can be any supported type.
	 * If the first argument is true, the second argument is returned;
	 * otherwise, the third argument is returned.
	 * </p>
	 * 
	 * @param stack
	 *            Stack of incoming arguments.
	 */
	public void run(Stack stack) throws ParseException {
		// Check if stack is null
		if (null == stack) {
			throw new ParseException("Stack argument null");
		}

		Object result = null;
		
		boolean condition = false;

		Object param3 = stack.pop();
		Object param2 = stack.pop();
		Object param1 = stack.pop();
		
		if (param1 instanceof Number)
		{
			condition = (((Number)param1).doubleValue() > 0d);
		}
		else if (param1 instanceof Boolean)
		{
			condition = ((Boolean)param1).booleanValue();
		}
		else
		{
			throw new ParseException("Invalid parameter type for Parameter 1");
		}
		
		if (condition)
		{
			result = param2;
		}
		else
		{
			result = param3;
		}

		// push the result on the inStack
		stack.push(result);
	}

}