/*
 *  dJEP - DESCRIPTION OF PACKAGE
 *  Copyright (C) 2004 Ross M. Lodge
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  The author of this program grants you the ability to use this code
 *  in conjunction with code that is covered under the Open Gaming License
 *
 *  Min.java
 *
 *  Created on Jan 31, 2004, 10:39:42 AM
 */
package com.electronicmuse.djep.function;

import java.util.Stack;

import com.electronicmuse.djep.ParseException;

/**
 * <p>
 * This class returns the minimum of all entereted parameters; it accepts a
 * variable number of parameters, which are assumed to be of number type.
 * </p>
 * 
 * @author Ross M. Lodge
 *  
 */
public class Min extends PostfixMathCommand
{

	/**
	 * <p>
	 * Initializes the number of parameters to = -1, indicating a variable
	 * number of parameters.
	 * </p>
	 *  
	 */
	public Min()
	{
		super();
		numberOfParameters = -1;
	}

	/**
	 * <p>
	 * Calculates the minimum of the parameters on the stack, all of which are
	 * assumed to be of type double.
	 * </p>
	 * 
	 * @param stack
	 *            Stack of incoming arguments.
	 */
	public void run(Stack stack) throws ParseException
	{
		// Check if stack is null
		if (null == stack)
		{
			throw new ParseException("Stack argument null");
		}

		Object param = null;
		double result = 0;
		boolean first = true;
		int i = 0;

		// repeat summation for each one of the current parameters
		while (i < curNumberOfParameters)
		{
			// get the parameter from the stack
			param = stack.pop();
			if (param instanceof Number)
			{
				// calculate the result
				if (first || ((Number) param).doubleValue() < result)
				{
					result = ((Number) param).doubleValue();
				}
			}
			else
			{
				throw new ParseException("Invalid parameter type");
			}
			first = false;

			i++;
		}

		// push the result on the inStack
		stack.push(new Double(result));
	}
}
